Struct tk::listbox::TkListbox

source ·
pub struct TkListbox<Inst: TkInstance>(/* private fields */);

Implementations

source

impl<Inst: TkInstance> TkListbox<Inst>

source

pub fn configure<Opts>( &self, opts: impl Into<PathOptsWidgets<Opts, ()>> ) -> InterpResult<()>

source

pub fn cget<Opt>(&self, _name_fn: fn(_: Obj) -> Opt) -> InterpResult<Obj>
where Opt: TkOption + Into<TkListboxOpt>,

source

pub fn grab(&self) -> InterpResult<()>

source

pub fn grab_global(&self) -> InterpResult<()>

source

pub fn grab_set_current(&self) -> InterpResult<()>

source

pub fn grab_release(&self) -> InterpResult<()>

source

pub fn grab_set(&self) -> InterpResult<()>

source

pub fn grab_set_global(&self) -> InterpResult<()>

source

pub fn grab_status(&self) -> InterpResult<()>

source

impl<Inst: TkInstance> TkListbox<Inst>

source

pub fn active(&self, index: impl Into<Index>) -> InterpResult<()>

source

pub fn curselection(&self) -> Result<Vec<c_int>, Enum2<DeError, InterpError>>

source

pub fn delete(&self, index: impl Into<Index>) -> InterpResult<()>

Deletes one element of the listbox.

Examples
use tcl::*;
use tk::*;
use tk::cmd::*;

fn concat( v: Vec<Obj> ) -> String {
    v.iter().map( |obj| obj.get_string() ).collect::<String>()
}

fn main() -> TkResult<()> {
    let tk = make_tk!()?;
    let root = tk.root();
    tk.set( "items", "a b c d e f g h i" );
    let lbox = root.add_listbox( "lbox" -listvariable("items") )?;

    lbox.delete(1)?;
    assert_eq!( concat( lbox.get_range(..)? ), "acdefghi" );

    Ok(())
}
source

pub fn delete_range(&self, range: impl Into<TkRange<Index>>) -> InterpResult<()>

Deletes one or more elements of the listbox.

Examples
use tcl::*;
use tk::*;
use tk::cmd::*;

fn concat( v: Vec<Obj> ) -> String {
    v.iter().map( |obj| obj.get_string() ).collect::<String>()
}

fn main() -> TkResult<()> {
    let tk = make_tk!()?;
    let root = tk.root();
    tk.set( "items", "a b c d e f g h i" );
    let lbox = root.add_listbox( "lbox" -listvariable("items") )?;

    lbox.delete_range(1..=1)?;
    assert_eq!( concat( lbox.get_range(..)? ), "acdefghi" );

    lbox.delete_range(6..)?;
    assert_eq!( concat( lbox.get_range(..)? ), "acdefg" );

    lbox.delete_range(..=1)?;
    assert_eq!( concat( lbox.get_range(..)? ), "defg" );

    lbox.delete_range(1..=2)?;
    assert_eq!( concat( lbox.get_range(..)? ), "dg" );

    lbox.delete_range(..)?;
    assert_eq!( concat( lbox.get_range(..)? ), "" );

    Ok(())
}
source

pub fn get( &self, index: impl Into<Index> ) -> Result<Obj, Enum2<InterpError, NotList>>

Returns the contents of the listbox element indicated by the index, or an empty string if first refers to a non-existent element.

Examples
use tcl::*;
use tk::*;
use tk::cmd::*;

fn main() -> TkResult<()> {
    let tk = make_tk!()?;
    let root = tk.root();

    tk.set( "items", "alpha beta gamma" );
    let lbox = root.add_listbox( "lbox" -listvariable("items") -height(5) )?.pack(())?;
    let expected = vec![ "alpha".to_owned(), "beta".to_owned(), "gamma".to_owned() ];

    assert_eq!( lbox.get(0)?.get_string(), expected[0] );
    assert_eq!( lbox.get(1)?.get_string(), expected[1] );
    assert_eq!( lbox.get(2)?.get_string(), expected[2] );
    assert_eq!( lbox.get(3)?.get_string(), "" );

    assert_eq!( lbox.get( TkListboxIndex::End )?.get_string(), expected[2] );

    Ok(())
}
source

pub fn get_range( &self, range: impl Into<TkRange<Index>> ) -> Result<Vec<Obj>, Enum2<InterpError, NotList>>

Returns a list whose elements are all of the listbox elements in the range.

Examples
use tcl::*;
use tk::*;
use tk::cmd::*;

fn main() -> TkResult<()> {
    let tk = make_tk!()?;
    let root = tk.root();

    tk.set( "items", "alpha beta gamma" );
    let lbox = root.add_listbox( "lbox" -listvariable("items") -height(5) )?.pack(())?;
    let expected = vec![ "alpha".to_owned(), "beta".to_owned(), "gamma".to_owned() ];

    assert_eq!( &lbox.get_range( ..  )?.iter().map( |obj| obj.get_string() ).collect::<Vec<_>>(), &expected );
    assert_eq!( &lbox.get_range(0..  )?.iter().map( |obj| obj.get_string() ).collect::<Vec<_>>(), &expected );
    assert_eq!( &lbox.get_range( ..=2)?.iter().map( |obj| obj.get_string() ).collect::<Vec<_>>(), &expected );
    assert_eq!( &lbox.get_range(0..=2)?.iter().map( |obj| obj.get_string() ).collect::<Vec<_>>(), &expected );

    assert_eq!( &lbox.get_range(1..=2)?.iter().map( |obj| obj.get_string() ).collect::<Vec<_>>(), &expected[1..=2] );

    Ok(())
}
source

pub fn index(&self, index: impl Into<Index>) -> InterpResult<c_longlong>

source

pub fn insert( &self, index: impl Into<Index>, elements: impl IntoIterator<Item = Obj> ) -> InterpResult<()>

source

pub fn insert_end( &self, elements: impl IntoIterator<Item = Obj> ) -> InterpResult<()>

source

pub fn itemcget<Opt, Val>( &self, index: impl Into<Index>, _name_fn: fn(_: Val) -> Opt ) -> InterpResult<Obj>
where Opt: TkOption + Into<TkListboxItemOpt>, Val: Into<Obj>,

source

pub fn itemconfigure<Opts>( &self, index: impl Into<Index>, opts: impl Into<PathOptsWidgets<Opts, ()>> ) -> InterpResult<()>

source

pub fn nearest(&self, y: c_int) -> InterpResult<c_longlong>

source

pub fn scan_mark(&self, x: c_int, y: c_int) -> InterpResult<()>

source

pub fn scan_dragto(&self, x: c_int, y: c_int) -> InterpResult<()>

source

pub fn see(&self, index: impl Into<Index>) -> InterpResult<()>

source

pub fn selection_anchor(&self, index: impl Into<Index>) -> InterpResult<()>

source

pub fn selection_clear(&self, index: impl Into<Index>) -> InterpResult<()>

source

pub fn selection_clear_range( &self, range: impl Into<TkRange<Index>> ) -> InterpResult<()>

source

pub fn selection_includes(&self, index: impl Into<Index>) -> InterpResult<bool>

source

pub fn selection_set(&self, index: impl Into<Index>) -> InterpResult<()>

source

pub fn selection_set_range( &self, range: impl Into<TkRange<Index>> ) -> InterpResult<()>

source

pub fn size(&self) -> InterpResult<c_longlong>

Methods from Deref<Target = Widget<Inst>>

source

pub fn path(&self) -> &'static str

source

pub fn add_widgets<Widgs, Shape>( &self, path_widgets: PathOptsWidgets<(), Widgs> ) -> InterpResult<CreatedWidgets<Inst>>
where Widgs: ConvertTuple, <Widgs as ConvertTuple>::Output: DomForest<(&'static str, &'static str), OptPair, Shape>,

Adds child widget(s) containing hierachical trees of children widgets, including geometry managers.

Examples
use tk::*;
use tk::cmd::*;

fn main() -> TkResult<()> {
    let tk = make_tk!()?;
    let root = tk.root();

    root.add_widgets(
        -pack(
            -button( -text("hello,tk!") -command("") )
            -pack( -button( -text("oops") ))
            -frame( -pack(
                -button( -text("exit") -command("destroy .") )
                -option_menu( "optmenu1", "my_opt", &[ "ALPHA", "BETA", "GAMMA" ])
            ))
        )
        -pack( -expand(1)
            -button( -text("demo") )
            -button( -text("demo") )
            -option_menu( "optmenu2", "your_opt", &[ "alpha", "beta", "gamma" ])
        )
    )?;

    Ok( main_loop() )
}
source

pub fn pack_configure<Opts>( &self, opts: impl Into<PathOptsWidgets<Opts, ()>> ) -> InterpResult<()>

source

pub fn pack_forget(&self) -> InterpResult<()>

source

pub fn pack_info(&self) -> InterpResult<HashMap<String, Obj>>

source

pub fn grid_configure<Opts>( &self, opts: impl Into<PathOptsWidgets<Opts, ()>> ) -> InterpResult<()>

source

pub fn grid_forget(&self) -> InterpResult<()>

source

pub fn grid_info(&self) -> InterpResult<HashMap<String, Obj>>

source

pub fn place_configure<Opts>( &self, opts: impl Into<PathOptsWidgets<Opts, ()>> ) -> InterpResult<()>

source

pub fn place_forget(&self) -> InterpResult<()>

source

pub fn place_info(&self) -> InterpResult<HashMap<String, Obj>>

source

pub fn grid_slaves<Opts>( &self, opts: impl Into<PathOptsWidgets<Opts, ()>> ) -> Result<Vec<Widget<Inst>>, Enum3<InterpError, NotList, WidgetNotFound>>

source

pub fn pack_slaves( &self ) -> Result<Vec<Widget<Inst>>, Enum3<InterpError, NotList, WidgetNotFound>>

source

pub fn place_slaves( &self ) -> Result<Vec<Widget<Inst>>, Enum3<InterpError, NotList, WidgetNotFound>>

source

pub fn has_used_input_methods(&self) -> InterpResult<bool>

source

pub fn use_input_methods(&self, should_use: bool) -> InterpResult<()>

source

pub fn inactive(&self) -> InterpResult<c_longlong>

source

pub fn inactive_reset(&self) -> InterpResult<c_longlong>

source

pub fn scaling(&self) -> InterpResult<c_double>

source

pub fn set_scaling(&self, number: c_double) -> InterpResult<()>

source

pub fn lower(&self) -> InterpResult<()>

source

pub fn lower_below(&self, below_this: &Self) -> InterpResult<()>

source

pub fn raise(&self) -> InterpResult<()>

source

pub fn raise_above(&self, above_this: &Self) -> InterpResult<()>

source

pub fn bind( &self, sequence: impl Into<TkEventSeq>, script: impl Into<Obj> ) -> InterpResult<()>

source

pub fn bind_more( &self, sequence: impl Into<TkEventSeq>, script: impl Into<Obj> ) -> InterpResult<()>

source

pub fn bindtags(&self, tags: &[&str]) -> InterpResult<()>

source

pub fn bindedtags(&self) -> Result<Vec<String>, Enum2<InterpError, NotList>>

source

pub fn event_generate<Opts>( &self, event: TkEvent, opts: impl Into<PathOptsWidgets<Opts, ()>> ) -> InterpResult<()>

Generates a window event and arranges for it to be processed just as if it had come from the window system. event provides a basic description of the event, such as shift_button_2() or paste(). If Window is empty the whole screen is meant, and coordinates are relative to the screen. Option-value pairs may be used to specify additional attributes of the event, such as the x and y mouse position; see EVENT FIELDS for more. If the -when option is not specified, the event is processed immediately: all of the handlers for the event will complete before the event generate command returns. If the -when option is specified then it determines when the event is processed. Certain events, such as key events, require that the window has focus to receive the event properly.

source

pub fn grid_anchor(&self, anchor: impl Into<Obj>) -> InterpResult<()>

source

pub fn grid_bbox( &self, grids: Grids ) -> Result<TkBBox, Enum2<DeError, InterpError>>

source

pub fn grid_columnconfigure<Opts>( &self, index: impl Into<Obj>, opts: impl Into<PathOptsWidgets<Opts, ()>> ) -> InterpResult<()>

source

pub fn grid_location( &self, x: c_int, y: c_int ) -> Result<Grid, Enum2<DeError, InterpError>>

source

pub fn grid_propagate(&self, do_propagate: bool) -> InterpResult<()>

source

pub fn grid_propagated(&self) -> InterpResult<bool>

source

pub fn grid_rowconfigure<Opts>( &self, index: impl Into<Obj>, opts: impl Into<PathOptsWidgets<Opts, ()>> ) -> InterpResult<()>

source

pub fn grid_remove(&self) -> InterpResult<()>

source

pub fn grid_size(&self) -> Result<Size, Enum2<DeError, InterpError>>

source

pub fn pack_propagate(&self, do_propagate: bool) -> InterpResult<()>

source

pub fn pack_propagated(&self) -> InterpResult<bool>

source

pub fn focus(&self) -> InterpResult<()>

source

pub fn focus_displayof(&self) -> InterpResult<Obj>

source

pub fn focus_force(&self) -> InterpResult<()>

source

pub fn focus_lastfor(&self) -> InterpResult<Obj>

source

pub fn winfo_atom(&self, name: &str) -> InterpResult<c_longlong>

source

pub fn winfo_atom_name(&self, id: c_longlong) -> InterpResult<String>

source

pub fn winfo_cells(&self) -> InterpResult<c_int>

source

pub fn winfo_children( &self ) -> Result<Vec<Widget<Inst>>, Enum3<InterpError, NotList, WidgetNotFound>>

source

pub fn winfo_class(&self) -> InterpResult<String>

source

pub fn winfo_colormap_full(&self) -> InterpResult<bool>

source

pub fn winfo_containing( &self, root_x: c_int, root_y: c_int ) -> InterpResult<String>

source

pub fn winfo_depth(&self) -> InterpResult<c_int>

source

pub fn winfo_fpixels(&self, number: TkDistance) -> InterpResult<c_double>

source

pub fn winfo_geometry( &self ) -> Result<TkGeometry, Enum2<InterpError, TkGeometryParseError>>

source

pub fn winfo_height(&self) -> InterpResult<c_int>

source

pub fn winfo_id(&self) -> InterpResult<String>

source

pub fn winfo_interps(&self) -> Result<Vec<String>, Enum2<InterpError, NotList>>

Returns a list whose members are the names of all Tcl interpreters (e.g. all Tk-based applications) currently registered for the display of window.

source

pub fn winfo_ismapped(&self) -> InterpResult<bool>

source

pub fn winfo_manager(&self) -> InterpResult<String>

Returns the name of the geometry manager currently responsible for window, or an empty string if window is not managed by any geometry manager. The name is usually the name of the Tcl command for the geometry manager, such as pack or place. If the geometry manager is a widget, such as canvases or text, the name is the widget’s class command, such as canvas.

Examples
use tk::*;
use tk::cmd::*;

fn main() -> TkResult<()> {
    let mut tk = make_tk!()?;
    let root = tk.root();
    let label = root.add_label( -text("lorum") )?.pack(())?;
    Ok( assert_eq!( label.winfo_manager().unwrap().as_str(), "pack" ))
}
source

pub fn winfo_name(&self) -> InterpResult<String>

source

pub fn winfo_parent(&self) -> InterpResult<Option<String>>

source

pub fn winfo_pathname(&self, id: c_ulong) -> InterpResult<String>

source

pub fn winfo_pixels(&self, number: TkDistance) -> InterpResult<c_int>

source

pub fn winfo_pointerx(&self) -> InterpResult<Option<c_int>>

source

pub fn winfo_pointerxy( &self ) -> Result<Option<TkCoord>, Enum2<DeError, InterpError>>

source

pub fn winfo_pointery(&self) -> InterpResult<Option<c_int>>

source

pub fn winfo_reqheight(&self) -> InterpResult<c_int>

source

pub fn winfo_reqwidth(&self) -> InterpResult<c_int>

source

pub fn winfo_rgb( &self, color: TkColor<'_> ) -> Result<TkRGB, Enum2<DeError, InterpError>>

source

pub fn winfo_rootx(&self) -> InterpResult<c_int>

source

pub fn winfo_rooty(&self) -> InterpResult<c_int>

source

pub fn winfo_screen( &self ) -> Result<TkScreenName, Enum2<InterpError, TkScreenNameParseError>>

source

pub fn winfo_screencells(&self) -> InterpResult<c_int>

source

pub fn winfo_screendepth(&self) -> InterpResult<c_int>

source

pub fn winfo_screenheight(&self) -> InterpResult<c_int>

source

pub fn winfo_screenmmheight(&self) -> InterpResult<c_int>

source

pub fn winfo_screenmmwidth(&self) -> InterpResult<c_int>

source

pub fn winfo_screenvisual( &self ) -> Result<TkVisualClass, Enum2<DeError, InterpError>>

source

pub fn winfo_screenwidth(&self) -> InterpResult<c_int>

source

pub fn winfo_server(&self) -> InterpResult<String>

source

pub fn winfo_toplevel(&self) -> InterpResult<TkToplevel<Inst>>

source

pub fn winfo_viewable(&self) -> InterpResult<bool>

source

pub fn winfo_visual(&self) -> Result<TkVisualClass, Enum2<DeError, InterpError>>

source

pub fn winfo_visualid(&self) -> InterpResult<String>

source

pub fn winfo_visualsavailable( &self ) -> Result<Vec<(TkVisualClass, c_int)>, Enum4<DeError, InterpError, NotList, NotSeqOf<(TkVisualClass, c_int)>>>

source

pub fn winfo_visualsavailable_includeids( &self ) -> Result<Vec<(TkVisualClass, c_int, String)>, Enum4<DeError, InterpError, NotList, NotSeqOf<(TkVisualClass, c_int, String)>>>

source

pub fn winfo_vrootheight(&self) -> InterpResult<c_int>

source

pub fn winfo_vrootwidth(&self) -> InterpResult<c_int>

source

pub fn winfo_vrootx(&self) -> InterpResult<c_int>

source

pub fn winfo_vrooty(&self) -> InterpResult<c_int>

source

pub fn winfo_width(&self) -> InterpResult<c_int>

source

pub fn winfo_x(&self) -> InterpResult<c_int>

source

pub fn winfo_y(&self) -> InterpResult<c_int>

source

pub fn set_wm_aspect( &self, min_numer: impl Into<Obj>, min_denom: impl Into<Obj>, max_numer: impl Into<Obj>, max_denom: impl Into<Obj> ) -> InterpResult<()>

source

pub fn wm_aspect( &self ) -> Result<(c_int, c_int, c_int, c_int), Enum2<DeError, InterpError>>

source

pub fn wm_clear_aspect(&self) -> InterpResult<()>

source

pub fn wm_attributes(&self) -> InterpResult<Obj>

source

pub fn set_wm_attributes<Opts>( &self, opts: impl Into<PathOptsWidgets<Opts, ()>> ) -> InterpResult<()>

source

pub fn set_wm_client(&self, name: &str) -> InterpResult<()>

source

pub fn wm_client(&self) -> InterpResult<String>

source

pub fn set_wm_colormapwindows( &self, windows: Vec<Widget<Inst>> ) -> InterpResult<()>

source

pub fn wm_colormapwindows( &self ) -> Result<Vec<Widget<Inst>>, Enum3<InterpError, NotList, WidgetNotFound>>

source

pub fn set_wm_command(&self, command: impl Into<Obj>) -> InterpResult<()>

source

pub fn wm_command(&self) -> InterpResult<Obj>

source

pub fn wm_deiconify(&self) -> InterpResult<()>

source

pub fn set_wm_focusmodel(&self, focus_model: TkFocusModel) -> InterpResult<()>

source

pub fn wm_focusmodel(&self) -> Result<TkFocusModel, Enum2<DeError, InterpError>>

source

pub fn wm_forget(&self) -> InterpResult<()>

source

pub fn wm_frame(&self) -> InterpResult<String>

source

pub fn set_wm_geometry(&self, geometry: TkGeometry) -> InterpResult<()>

source

pub fn wm_geometry( &self ) -> Result<TkGeometry, Enum2<InterpError, TkGeometryParseError>>

source

pub fn set_wm_grid(&self, acceptable_size: TkAcceptableSize) -> InterpResult<()>

source

pub fn wm_grid( &self ) -> Result<TkAcceptableSize, Enum3<InterpError, NotList, TkAcceptableSizeParseError>>

source

pub fn set_wm_group(&self, leader: Widget<Inst>) -> InterpResult<()>

source

pub fn clear_wm_group(&self) -> InterpResult<()>

source

pub fn wm_group(&self) -> InterpResult<Option<Widget<Inst>>>

source

pub fn set_wm_iconbitmap(&self, bitmap: &str) -> InterpResult<()>

source

pub fn clear_wm_iconbitmap(&self) -> InterpResult<()>

source

pub fn wm_iconbitmap(&self) -> InterpResult<String>

source

pub fn wm_iconify(&self) -> InterpResult<()>

source

pub fn set_wm_iconmask(&self, bitmap: &str) -> InterpResult<()>

source

pub fn clear_wm_iconmask(&self) -> InterpResult<()>

source

pub fn wm_iconmask(&self) -> InterpResult<Option<String>>

source

pub fn set_wm_iconname(&self, name: &str) -> InterpResult<()>

source

pub fn wm_iconname(&self) -> InterpResult<String>

source

pub fn set_wm_iconphoto( &self, image: &str, extra_images: Option<&[&str]> ) -> InterpResult<()>

source

pub fn set_wm_iconposition(&self, x: c_int, y: c_int) -> InterpResult<()>

source

pub fn clear_wm_iconposition(&self) -> InterpResult<()>

source

pub fn wm_iconposition(&self) -> Result<TkCoord, Enum2<DeError, InterpError>>

source

pub fn set_wm_iconwindow(&self, icon_window: Widget<Inst>) -> InterpResult<()>

source

pub fn clear_wm_iconwindow(&self) -> InterpResult<()>

source

pub fn wm_iconwindow(&self) -> InterpResult<Option<Widget<Inst>>>

source

pub fn set_wm_maxsize(&self, width: c_int, height: c_int) -> InterpResult<()>

source

pub fn wm_maxsize(&self) -> Result<TkSize, Enum2<DeError, InterpError>>

source

pub fn set_wm_minsize(&self, width: c_int, height: c_int) -> InterpResult<()>

source

pub fn wm_minsize(&self) -> Result<TkSize, Enum2<DeError, InterpError>>

source

pub fn set_wm_overrideredirect( &self, overrideredirect: bool ) -> InterpResult<()>

source

pub fn wm_overrideredirect(&self) -> InterpResult<bool>

source

pub fn set_wm_positionfrom(&self, who: TkRequester) -> InterpResult<()>

source

pub fn clear_wm_positionfrom(&self) -> InterpResult<()>

source

pub fn wm_positionfrom( &self ) -> Result<Option<TkRequester>, Enum2<InterpError, TkRequesterParseError>>

source

pub unsafe fn set_wm_protocol( &self, name: &str, command: impl Into<Obj> ) -> InterpResult<()>

source

pub fn clear_wm_protocol_command(&self, name: &str) -> InterpResult<Obj>

source

pub unsafe fn wm_protocol_command( &self, name: &str ) -> InterpResult<Option<Obj>>

source

pub fn wm_protocol( &self ) -> Result<Vec<TkHandler>, Enum3<NotSeqOf<TkHandler>, NotList, InterpError>>

source

pub fn set_wm_resizable( &self, width_resizable: bool, height_resizable: bool ) -> InterpResult<()>

source

pub fn wm_resizable( &self ) -> Result<TkResizable, Enum2<InterpError, TkResizableParseError>>

source

pub fn set_wm_sizefrom(&self, who: TkRequester) -> InterpResult<()>

source

pub fn clear_wm_sizefrom(&self) -> InterpResult<()>

source

pub fn wm_sizefrom( &self ) -> Result<Option<TkRequester>, Enum2<InterpError, TkRequesterParseError>>

source

pub fn wm_stackorder( &self ) -> Result<Vec<Widget<Inst>>, Enum3<InterpError, NotList, WidgetNotFound>>

source

pub fn wm_stackorder_isabove(&self, widget: &Widget<Inst>) -> InterpResult<bool>

source

pub fn wm_stackorder_isbelow(&self, widget: &Widget<Inst>) -> InterpResult<bool>

source

pub fn set_wm_state(&self, new_state: TkState) -> InterpResult<()>

source

pub fn wm_state(&self) -> Result<TkState, Enum2<DeError, InterpError>>

source

pub fn set_wm_title(&self, title: impl Into<Obj>) -> InterpResult<()>

source

pub fn wm_title(&self) -> InterpResult<String>

source

pub fn set_wm_transient(&self, master: &TkToplevel<Inst>) -> InterpResult<()>

source

pub fn clear_wm_transient(&self) -> InterpResult<()>

source

pub fn wm_transient(&self) -> InterpResult<Option<TkToplevel<Inst>>>

source

pub fn wm_withdraw(&self) -> InterpResult<()>

source

pub fn font_actual<'a, Opt, Opts>( &self, font: Font<'a, Opts>, _option: Opt, ch: Option<char> ) -> InterpResult<Obj>

Returns the value of the actual attributes that are obtained when font is used on window’s display; the actual attribute obtained may differ from the attribute requested due to platform-dependent limitations, such as the availability of font families and point sizes. If the char argument is supplied, the font attributes returned will be those of the specific font used to render that character, which will be different from the base font if the base font does not contain the given character.

source

pub fn font_actual_get_all<'a, Opts>( &self, font: Font<'a, Opts> ) -> InterpResult<Obj>

Returns a list of all the atual attributes and their values that are obtained when font is used on window’s display; the actual attributes obtained may differ from the attributes requested due to platform-dependent limitations, such as the availability of font families and point sizes. If the char argument is supplied, the font attributes returned will be those of the specific font used to render that character, which will be different from the base font if the base font does not contain the given character.

source

pub fn font_families(&self) -> Result<Vec<String>, Enum2<InterpError, NotList>>

source

pub fn font_measure<'a, Opts>( &self, font: Font<'a, Opts>, text: impl Into<String> ) -> InterpResult<c_longlong>

source

pub fn font_metrics<'a, Opt, Opts>( &self, font: Font<'a, Opts>, _opt: Opt ) -> InterpResult<Obj>

source

pub fn font_metrics_get_all<'a, Opts>( &self, font: Font<'a, Opts> ) -> Result<Vec<OptPair>, Enum3<InterpError, NotList, NotSeqOf<OptPair>>>